pub enum FileSystemError {
GameInfoNotFound(PathBuf),
InvalidGamePath(PathBuf),
GameInfoParseError,
}Expand description
Errors that can occur when loading or using the FileSystem.
Variants
GameInfoNotFound(PathBuf)
The gameinfo.txt file was not found in the specified path.
InvalidGamePath(PathBuf)
The provided game path is invalid (e.g., it has no parent or file name).
GameInfoParseError
The gameinfo.txt file could not be parsed.