FileSystem

Struct FileSystem 

pub struct FileSystem<P: PackFile> { /* private fields */ }
Core FileSystem representation holding physical directories and loaded pack files.

Implementations

Source

impl<P: PackFile> FileSystem<P>

pub fn load_from_path<G: GameInfoProvider>( game_path: &Path, options: &FileSystemOptions, ) -> Result<Self, FileSystemError>

Loads the filesystem from a specific game directory (where gameinfo.txt resides).

pub fn root_path(&self) -> &PathBuf

pub fn search_path_dirs(&self) -> &HashMap<String, Vec<PathBuf>>

pub fn search_path_dirs_mut(&mut self) -> &mut HashMap<String, Vec<PathBuf>>

pub fn search_path_vpks(&self) -> &HashMap<String, Vec<Arc<P>>>

pub fn search_path_vpks_mut(&mut self) -> &mut HashMap<String, Vec<Arc<P>>>

pub fn find_file(&self, file_path: &str, search_path: &str) -> Option<PathBuf>

pub fn read( &self, file_path: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<Vec<u8>>

Reads data from the internal mounted paths using standard Source Engine priorities.

pub fn read_for_map( &self, map_pack: Option<&P>, file_path: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<Vec<u8>>

Same as read, but takes an optional active map pack file which gets highest priority.

pub fn read_str( &self, file_path: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<String>

pub fn find_asset( &self, name: &str, prefix: &str, suffix: &str, search_path: &str, ) -> Option<PathBuf>

Finds an asset’s PathBuf without reading its contents into memory.

pub fn read_asset( &self, name: &str, prefix: &str, suffix: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<Vec<u8>>

Reads any asset as raw bytes, safely appending prefix and suffix if missing.

pub fn read_asset_str( &self, name: &str, prefix: &str, suffix: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<String>

Reads any asset as a UTF-8 string, safely appending prefix and suffix if missing.

pub fn read_material( &self, name: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<Vec<u8>>

Reads a material file (.vmt).

pub fn read_material_str( &self, name: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<String>

Reads a material file (.vmt) as a UTF-8 string.

pub fn read_model( &self, name: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<Vec<u8>>

Reads a model file (.mdl).

pub fn read_model_str( &self, name: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<String>

Reads a model file (.mdl) as a UTF-8 string.

pub fn read_sound_str( &self, name: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<String>

Reads a sound file (.wav or fallback to .mp3) as a UTF-8 string.