Module providers

Module providers 

Structs

DummyVpk
A dummy implementation that ignores VPK files. Forces the FileSystem to read exclusively from physical disk directories.
P2GameInfo
Portal 2 has a unique feature: DLC folders. They aren’t added to SearchPaths; the game automatically mounts the content if it exists, incrementing the DLC number
SimpleGameInfo
A basic VDF parser specifically for extracting SearchPaths from gameinfo.txt
SimpleWithMount
A GameInfoProvider that also parses mount.cfg for additional search paths, typically found in Source engine games like Garry’s Mod or P2CE.