PackFile

Trait PackFile 

pub trait PackFile {
    // Required methods
    fn open<P: AsRef<Path>>(path: P) -> Option<Self>
       where Self: Sized;
    fn has_entry(&self, path: &str) -> bool;
    fn read_entry(&self, path: &str) -> Option<Vec<u8>>;
}
Represents a loaded VPK or generic pack file archive.

Required Methods

fn open<P: AsRef<Path>>(path: P) -> Option<Self>
where Self: Sized,

Opens a pack file from the given physical path.

fn has_entry(&self, path: &str) -> bool

Checks if a given file entry exists within the pack file.

fn read_entry(&self, path: &str) -> Option<Vec<u8>>

Reads the specified entry’s binary data from the pack file.

Implementors