FileSystem

Struct FileSystem 

pub struct FileSystem<P: PackFile> { /* private fields */ }
Core FileSystem representation holding physical directories and loaded pack files.

Implementations

Source

impl<P: PackFile> FileSystem<P>

pub fn load_from_path<G: GameInfoProvider>( game_path: &Path, options: &FileSystemOptions, ) -> Option<Self>

Loads the filesystem from a specific game directory (where gameinfo.txt resides).

pub fn search_path_dirs(&self) -> &HashMap<String, Vec<PathBuf>>

pub fn search_path_dirs_mut(&mut self) -> &mut HashMap<String, Vec<PathBuf>>

pub fn search_path_vpks(&self) -> &HashMap<String, Vec<Arc<P>>>

pub fn search_path_vpks_mut(&mut self) -> &mut HashMap<String, Vec<Arc<P>>>

pub fn find_file(&self, file_path: &str, search_path: &str) -> Option<PathBuf>

pub fn read( &self, file_path: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<Vec<u8>>

Reads data from the internal mounted paths using standard Source Engine priorities.

pub fn read_for_map( &self, map_pack: Option<&P>, file_path: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<Vec<u8>>

Same as read, but takes an optional active map pack file which gets highest priority.

pub fn read_str( &self, file_path: &str, search_path: &str, prioritize_vpks: bool, ) -> Option<String>