Module providers
source_
fs
0.3.0
Module providers
Module Items
Structs
In crate source_
fs
source_fs
Module
providers
Structs

Dummy
Vpk
A dummy implementation that ignores VPK files. Forces the FileSystem to read exclusively from physical disk directories.
P2Game
Info
Portal 2 has a unique feature: DLC folders. They aren’t added to SearchPaths; the game automatically mounts the content if it exists, incrementing the DLC number
Simple
Game
Info
A basic VDF parser specifically for extracting SearchPaths from gameinfo.txt
Simple
With
Mount
A GameInfoProvider that also parses
mount.cfg
for additional search paths, typically found in Source engine games like Garry’s Mod or P2CE.